==> ejc-scientific-api-3.0.0-20250318.033513-62-sources.jar: com/ejianc/business/scientific/result/SoftRegisterVO.java <==
package com.ejianc.business.scientific.result;


import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 专利管理-软著登记
 * 
 * @author generator
 * 
 */
public class SoftRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // projectName
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // orgName
    private Long parentOrgId; // 父级组织(二级单位Id)
    private String parentOrgCode; // 父级组织编码(二级单位code)
    private String parentOrgName; // 父级组织(二级单位name)
    private Integer billState; // 单据状态（审批必须字段）
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long deptId; // 经办部门
    private String deptName; // 经办部门名称
    private String softName; // 软著名称
    private Integer patentType; // 专利类型  1-发明 2-实用新型 3-外观
    private String memo; // 软著摘要
    private String softPerson; // 著作权人
    private String registerCode; // 登记号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date approveDate; // 登记批准日期
    private Integer validityDate; // 有效期-1--10年, 2--20年
    private String inventPerson; // 发明人
    private Integer lawType; // 法律状态 1-有效 2-失效
    private String lawTypeName; // 法律状态 1-有效 2-失效
    private Long scientificProjectId; // 所属科研项目id
    private String scientificProjectName; // 所属科研项目name
    private String versionCode; // 版本号
    private String billStateName; // 单据状态（审批必须字段）

    public String getLawTypeName() {
        return lawTypeName;
    }

    public void setLawTypeName(String lawTypeName) {
        this.lawTypeName = lawTypeName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getSoftName() {
        return softName;
    }

    public void setSoftName(String softName) {
        this.softName = softName;
    }
    public Integer getPatentType() {
        return patentType;
    }

    public void setPatentType(Integer patentType) {
        this.patentType = patentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSoftPerson() {
        return softPerson;
    }

    public void setSoftPerson(String softPerson) {
        this.softPerson = softPerson;
    }
    public String getRegisterCode() {
        return registerCode;
    }

    public void setRegisterCode(String registerCode) {
        this.registerCode = registerCode;
    }
    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
    public Integer getValidityDate() {
        return validityDate;
    }

    public void setValidityDate(Integer validityDate) {
        this.validityDate = validityDate;
    }
    public String getInventPerson() {
        return inventPerson;
    }

    public void setInventPerson(String inventPerson) {
        this.inventPerson = inventPerson;
    }
    public Integer getLawType() {
        return lawType;
    }

    public void setLawType(Integer lawType) {
        this.lawType = lawType;
    }
    @ReferSerialTransfer(referCode="sci-project")
    public Long getScientificProjectId() {
        return scientificProjectId;
    }
    @ReferDeserialTransfer
    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getVersionCode() {
        return versionCode;
    }

    public void setVersionCode(String versionCode) {
        this.versionCode = versionCode;
    }
    
}

==> ejc-scientific-api-3.0.0-20250415.102803-73-sources.jar: com/ejianc/business/scientific/result/SoftRegisterVO.java <==
package com.ejianc.business.scientific.result;


import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 专利管理-软著登记
 * 
 * @author generator
 * 
 */
public class SoftRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // projectName
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // orgName
    private Long parentOrgId; // 父级组织(二级单位Id)
    private String parentOrgCode; // 父级组织编码(二级单位code)
    private String parentOrgName; // 父级组织(二级单位name)
    private Integer billState; // 单据状态（审批必须字段）
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long deptId; // 经办部门
    private String deptName; // 经办部门名称
    private String softName; // 软著名称
    private Integer patentType; // 专利类型  1-发明 2-实用新型 3-外观设计
    private String memo; // 软著摘要
    private String softPerson; // 著作权人
    private String registerCode; // 登记号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date approveDate; // 登记批准日期
    private Integer validityDate; // 有效期-1--10年, 2--20年
    private String inventPerson; // 发明人
    private Integer lawType; // 法律状态 1-有效 2-失效
    private String lawTypeName; // 法律状态 1-有效 2-失效
    private Long scientificProjectId; // 所属科研项目id
    private String scientificProjectName; // 所属科研项目name
    private String versionCode; // 版本号
    private String billStateName; // 单据状态（审批必须字段）
    private Long applyId; // 申请单id
    private String applyCode; // 申请单编码

    public String getLawTypeName() {
        return lawTypeName;
    }

    public void setLawTypeName(String lawTypeName) {
        this.lawTypeName = lawTypeName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getSoftName() {
        return softName;
    }

    public void setSoftName(String softName) {
        this.softName = softName;
    }
    public Integer getPatentType() {
        return patentType;
    }

    public void setPatentType(Integer patentType) {
        this.patentType = patentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSoftPerson() {
        return softPerson;
    }

    public void setSoftPerson(String softPerson) {
        this.softPerson = softPerson;
    }
    public String getRegisterCode() {
        return registerCode;
    }

    public void setRegisterCode(String registerCode) {
        this.registerCode = registerCode;
    }
    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
    public Integer getValidityDate() {
        return validityDate;
    }

    public void setValidityDate(Integer validityDate) {
        this.validityDate = validityDate;
    }
    public String getInventPerson() {
        return inventPerson;
    }

    public void setInventPerson(String inventPerson) {
        this.inventPerson = inventPerson;
    }
    public Integer getLawType() {
        return lawType;
    }

    public void setLawType(Integer lawType) {
        this.lawType = lawType;
    }
    @ReferSerialTransfer(referCode="sci-project")
    public Long getScientificProjectId() {
        return scientificProjectId;
    }
    @ReferDeserialTransfer
    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getVersionCode() {
        return versionCode;
    }

    public void setVersionCode(String versionCode) {
        this.versionCode = versionCode;
    }

    @ReferSerialTransfer(referCode="sci-soft-apply")
    public Long getApplyId() {
        return applyId;
    }

    @ReferDeserialTransfer
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }
}
